@@ -35,7 +35,7 @@
 #include <glib/gi18n.h>
 
 #include <gtk/gtk.h>
-#ifdef HAVE_LIBNOTIFY
+#ifdef HAVE_NOTIFY
 #include <libnotify/notify.h>
 #endif
 #include <packagekit-glib2/packagekit.h>
@@ -56,7 +56,7 @@
 
 static void     gpk_check_update_finalize	(GObject	     *object);
 
-#ifdef HAVE_LIBNOTIFY
+#ifdef HAVE_NOTIFY
 static void	gpk_check_update_libnotify_cb (NotifyNotification *notification, gchar *action, gpointer data);
 #endif
 
@@ -559,7 +559,7 @@ gpk_check_update_activate_update_cb (GtkStatusIcon *status_icon, GpkCheckUpdate
 	}
 }
 
-#ifdef HAVE_LIBNOTIFY
+#ifdef HAVE_NOTIFY
 /**
  * gpk_check_update_libnotify_cb:
  **/
@@ -780,27 +780,6 @@ gpk_check_update_check_on_battery (GpkCheckUpdate *cupdate)
 	return FALSE;
 }
 
-/**
- * gpk_check_update_get_update_policy:
- **/
-static GpkUpdateEnum
-gpk_check_update_get_update_policy (GpkCheckUpdate *cupdate)
-{
-	GpkUpdateEnum update;
-	gchar *updates;
-
-	g_return_val_if_fail (GPK_IS_CHECK_UPDATE (cupdate), FALSE);
-
-	updates = g_settings_get_string (cupdate->priv->settings, GPK_SETTINGS_AUTO_UPDATE);
-	if (updates == NULL) {
-		egg_warning ("'%s' settings key is null!", GPK_SETTINGS_AUTO_UPDATE);
-		return GPK_UPDATE_ENUM_UNKNOWN;
-	}
-	update = gpk_update_enum_from_text (updates);
-	g_free (updates);
-	return update;
-}
-
 /**
  * gpk_check_update_notify_doing_updates:
  **/
@@ -920,7 +899,7 @@ gpk_check_update_get_updates_finished_cb (GObject *object, GAsyncResult *res, Gp
 	}
 
 	/* do we do the automatic updates? */
-	update = gpk_check_update_get_update_policy (cupdate);
+	update = g_settings_get_enum (cupdate->priv->settings, GPK_SETTINGS_AUTO_UPDATE);
 	if (update == GPK_UPDATE_ENUM_UNKNOWN) {
 		egg_warning ("policy unknown");
 		goto out;
