@@ -258,45 +258,10 @@ static const PkEnumMatch enum_message_icon_name[] = {
 	{PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED,	"dialog-information"},
 	{PK_MESSAGE_ENUM_REPO_METADATA_DOWNLOAD_FAILED,	"dialog-warning"},
 	{PK_MESSAGE_ENUM_REPO_FOR_DEVELOPERS_ONLY,	"dialog-warning"},
+	{PK_MESSAGE_ENUM_OTHER_UPDATES_HELD_BACK,	"dialog-information"},
 	{0, NULL}
 };
 
-static const PkEnumMatch enum_update[] = {
-	{GPK_UPDATE_ENUM_UNKNOWN,		"unknown"},	/* fall though value */
-	{GPK_UPDATE_ENUM_ALL,			"all"},
-	{GPK_UPDATE_ENUM_SECURITY,		"security"},
-	{GPK_UPDATE_ENUM_NONE,			"none"},
-	{0, NULL}
-};
-
-/**
- * gpk_update_enum_from_text:
- * @update: Text describing the enumerated type
- *
- * Converts a text enumerated type to its unsigned integer representation
- *
- * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
- **/
-GpkUpdateEnum
-gpk_update_enum_from_text (const gchar *update)
-{
-	return pk_enum_find_value (enum_update, update);
-}
-
-/**
- * gpk_update_enum_to_text:
- * @update: The enumerated type value
- *
- * Converts a enumerated type to its text representation
- *
- * Return value: the enumerated constant value, e.g. "available"
- **/
-const gchar *
-gpk_update_enum_to_text (GpkUpdateEnum update)
-{
-	return pk_enum_find_string (enum_update, update);
-}
-
 /**
  * gpk_media_type_enum_to_localised_text:
  **/
@@ -521,6 +486,12 @@ gpk_error_enum_to_localised_text (PkErrorEnum code)
 	case PK_ERROR_ENUM_PACKAGE_DATABASE_CHANGED:
 		text = _("The package database was changed");
 		break;
+	case PK_ERROR_ENUM_PROVIDE_TYPE_NOT_SUPPORTED:
+		text = _("Virtual provide type is not supported");
+		break;
+	case PK_ERROR_ENUM_INSTALL_ROOT_INVALID:
+		text = _("Install root is invalid");
+		break;
 	default:
 		egg_warning ("Unknown error");
 	}
@@ -760,6 +731,12 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
 	case PK_ERROR_ENUM_PACKAGE_DATABASE_CHANGED:
 		text = _("The package database was changed while the request was running.");
 		break;
+	case PK_ERROR_ENUM_PROVIDE_TYPE_NOT_SUPPORTED:
+		text = _("The virtual provide type is not supported by this system.");
+		break;
+	case PK_ERROR_ENUM_INSTALL_ROOT_INVALID:
+		text = _("The install root is invalid. Please contact your administrator.");
+		break;
 	default:
 		egg_warning ("Unknown error, please report a bug at " GPK_BUGZILLA_URL ".\n"
 			    "More information is available in the detailed report.");
@@ -910,6 +887,9 @@ gpk_message_enum_to_localised_text (PkMessageEnum message)
 	case PK_MESSAGE_ENUM_REPO_FOR_DEVELOPERS_ONLY:
 		text = _("This software source is for developers only");
 		break;
+	case PK_MESSAGE_ENUM_OTHER_UPDATES_HELD_BACK:
+		text = _("Other updates have been held back");
+		break;
 	default:
 		egg_warning ("message unrecognised: %i", message);
 	}
@@ -2034,17 +2014,6 @@ gpk_enum_test (gpointer data)
 	}
 	egg_test_success (test, NULL);
 
-	/************************************************************/
-	egg_test_title (test, "check we convert all the update bitfield");
-	for (i=0; i<=GPK_UPDATE_ENUM_UNKNOWN; i++) {
-		string = gpk_update_enum_to_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
 	egg_test_end (test);
 }
 #endif
