@@ -24,6 +24,7 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <packagekit-glib2/packagekit.h>
+#include <gio/gdesktopappinfo.h>
 
 #include "gpk-helper-run.h"
 #include "gpk-marshal.h"
@@ -42,13 +43,12 @@ struct GpkHelperRunPrivate
 {
 	GtkBuilder		*builder;
 	GtkListStore		*list_store;
-	gchar			*full_path;
 };
 
 enum {
 	GPK_CHOOSER_COLUMN_ICON,
 	GPK_CHOOSER_COLUMN_TEXT,
-	GPK_CHOOSER_COLUMN_FULL_PATH,
+	GPK_CHOOSER_COLUMN_FILENAME,
 	GPK_CHOOSER_COLUMN_LAST
 };
 
@@ -58,23 +58,34 @@ G_DEFINE_TYPE (GpkHelperRun, gpk_helper_run, G_TYPE_OBJECT)
  * gpk_helper_run_path:
  **/
 static gboolean
-gpk_helper_run_path (GpkHelperRun *helper)
+gpk_helper_run_path (GpkHelperRun *helper, const gchar *filename)
 {
 	gboolean ret = FALSE;
 	GError *error = NULL;
+	GAppInfo *app = NULL;
+	GAppLaunchContext *context = NULL;
 
 	/* check have value */
-	if (helper->priv->full_path == NULL) {
+	if (filename == NULL) {
 		egg_warning ("no full path");
 		goto out;
 	}
 
-	ret = g_spawn_command_line_async (helper->priv->full_path, &error);
+	/* launch application */
+	app = G_APP_INFO(g_desktop_app_info_new_from_filename (filename));
+	context = G_APP_LAUNCH_CONTEXT(gdk_app_launch_context_new ());
+//	app = (GAppInfo*)g_desktop_app_info_new_from_filename (filename);
+//	context = (GAppLaunchContext*)gdk_app_launch_context_new ();
+	ret = g_app_info_launch (app, NULL, context, &error);
 	if (!ret) {
-		egg_warning ("failed to run: %s", error->message);
+		egg_warning ("failed to launch: %s", error->message);
 		g_error_free (error);
 	}
 out:
+	if (app != NULL)
+		g_object_unref (app);
+	if (context != NULL)
+		g_object_unref (context);
 	return ret;
 }
 
@@ -84,7 +95,25 @@ out:
 static void
 gpk_helper_run_button_run_cb (GtkWidget *widget, GpkHelperRun *helper)
 {
-	gpk_helper_run_path (helper);
+	GtkTreeView *treeview;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	GtkTreeSelection *selection;
+	gboolean ret;
+	gchar *filename;
+
+	/* get selection */
+	treeview = GTK_TREE_VIEW (gtk_builder_get_object (helper->priv->builder, "treeview_simple"));
+	selection = gtk_tree_view_get_selection (treeview);
+	ret = gtk_tree_selection_get_selected (selection, &model, &iter);
+	if (!ret) {
+		egg_warning ("failed to get selection");
+		return;
+	}
+
+	gtk_tree_model_get (model, &iter, GPK_CHOOSER_COLUMN_FILENAME, &filename, -1);
+	gpk_helper_run_path (helper, filename);
+	g_free (filename);
 }
 
 /**
@@ -113,10 +142,6 @@ gpk_helper_run_button_help_cb (GtkWidget *widget, GpkHelperRun *helper)
 static gboolean
 gpk_helper_run_delete_event_cb (GtkWidget *widget, GdkEvent *event, GpkHelperRun *helper)
 {
-	/* clear full_path */
-	g_free (helper->priv->full_path);
-	helper->priv->full_path = NULL;
-
 	widget = GTK_WIDGET (gtk_builder_get_object (helper->priv->builder, "dialog_simple"));
 	gtk_widget_hide (widget);
 	return FALSE;
@@ -131,17 +156,19 @@ gpk_helper_run_treeview_clicked_cb (GtkTreeSelection *selection, GpkHelperRun *h
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
+	gchar *filename = NULL;
 
 	/* This will only work in single or browse selection mode! */
 	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
-		g_free (helper->priv->full_path);
-		gtk_tree_model_get (model, &iter, GPK_CHOOSER_COLUMN_FULL_PATH, &helper->priv->full_path, -1);
+		g_free (filename);
+		gtk_tree_model_get (model, &iter, GPK_CHOOSER_COLUMN_FILENAME, &filename, -1);
 
 		/* show full path */
-		egg_debug ("selected row is: %s", helper->priv->full_path);
+		egg_debug ("selected row is: %s", filename);
 	} else {
 		egg_debug ("no row selected");
 	}
+	g_free (filename);
 }
 
 /**
@@ -154,6 +181,7 @@ gpk_helper_run_row_activated_cb (GtkTreeView *treeview, GtkTreePath *path,
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gboolean ret;
+	gchar *filename;
 
 	/* get selection */
 	model = gtk_tree_view_get_model (treeview);
@@ -163,9 +191,9 @@ gpk_helper_run_row_activated_cb (GtkTreeView *treeview, GtkTreePath *path,
 		return;
 	}
 
-	g_free (helper->priv->full_path);
-	gtk_tree_model_get (model, &iter, GPK_CHOOSER_COLUMN_FULL_PATH, &helper->priv->full_path, -1);
-	gpk_helper_run_path (helper);
+	gtk_tree_model_get (model, &iter, GPK_CHOOSER_COLUMN_FILENAME, &filename, -1);
+	gpk_helper_run_path (helper, filename);
+	g_free (filename);
 }
 
 /**
@@ -230,7 +258,7 @@ gpk_helper_run_add_desktop_file (GpkHelperRun *helper, const gchar *package_id,
 		goto out;
 	}
 
-	/* get exec */
+	/* get hidden */
 	hidden = g_key_file_get_boolean (file, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_HIDDEN, NULL);
 	if (hidden) {
 		egg_debug ("hidden, so ignoring %s", filename);
@@ -293,7 +321,7 @@ gpk_helper_run_add_desktop_file (GpkHelperRun *helper, const gchar *package_id,
 
 	gtk_list_store_set (helper->priv->list_store, &iter,
 			    GPK_CHOOSER_COLUMN_TEXT, fulltext,
-			    GPK_CHOOSER_COLUMN_FULL_PATH, exec,
+			    GPK_CHOOSER_COLUMN_FILENAME, filename,
 			    GPK_CHOOSER_COLUMN_ICON, icon, -1);
 out:
 	if (file != NULL)
@@ -369,8 +397,6 @@ gpk_helper_run_show (GpkHelperRun *helper, gchar **package_ids)
 
 	/* clear old list */
 	gtk_list_store_clear (helper->priv->list_store);
-	g_free (helper->priv->full_path);
-	helper->priv->full_path = NULL;
 
 	/* add all the apps */
 	len = gpk_helper_run_add_package_ids (helper, package_ids);
@@ -435,9 +461,6 @@ gpk_helper_run_init (GpkHelperRun *helper)
 
 	helper->priv = GPK_HELPER_RUN_GET_PRIVATE (helper);
 
-	/* initially nothing */
-	helper->priv->full_path = NULL;
-
 	/* get UI */
 	helper->priv->builder = gtk_builder_new ();
 	retval = gtk_builder_add_from_file (helper->priv->builder, GPK_DATA "/gpk-log.ui", &error);
@@ -521,7 +544,6 @@ gpk_helper_run_finalize (GObject *object)
 	widget = GTK_WIDGET (gtk_builder_get_object (helper->priv->builder, "dialog_simple"));
 	if (GTK_IS_WIDGET (widget))
 		gtk_widget_hide (widget);
-	g_free (helper->priv->full_path);
 	g_object_unref (helper->priv->builder);
 	g_object_unref (helper->priv->list_store);
 
