@@ -26,9 +26,7 @@
 
 #include <gtk/gtk.h>
 #include <sys/utsname.h>
-#include <gconf/gconf-client.h>
 #include <packagekit-glib2/packagekit.h>
-#include <unique/unique.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -157,8 +155,12 @@ gpk_pack_set_percentage (guint percentage)
 	/* no info */
 	if (percentage == 101) {
 		/* set pulsing */
-		if (pulse_id == 0)
+		if (pulse_id == 0) {
 			pulse_id = g_timeout_add (100, gpk_pack_percentage_pulse_cb, NULL);
+#if GLIB_CHECK_VERSION(2,25,8)
+			g_source_set_name_by_id (pulse_id, "[GpkServicePack] pulse");
+#endif
+		}
 		return;
 	}
 
@@ -612,19 +614,6 @@ out:
 	g_free (exclude);
 }
 
-/**
- * gpk_pack_message_received_cb
- **/
-static void
-gpk_pack_message_received_cb (UniqueApp *app, UniqueCommand command, UniqueMessageData *message_data, guint time_ms, gpointer data)
-{
-	GtkWindow *window;
-	if (command == UNIQUE_ACTIVATE) {
-		window = GTK_WINDOW (gtk_builder_get_object (builder, "window_prefs"));
-		gtk_window_present (window);
-	}
-}
-
 /**
  * gpk_pack_radio_updates_cb:
  **/
@@ -670,6 +659,25 @@ gpk_pack_radio_copy_cb (GtkWidget *widget2, gpointer data)
 	action = GPK_ACTION_ENUM_COPY;
 }
 
+/**
+ * gpk_pack_delete_event_cb:
+ **/
+static gboolean
+gpk_pack_delete_event_cb (GtkWidget *widget, GdkEvent *event, GtkApplication *application)
+{
+	gtk_application_quit (application);
+	return FALSE;
+}
+
+/**
+ * gpk_pack_button_close_cb:
+ **/
+static void
+gpk_pack_button_close_cb (GtkWidget *widget, GtkApplication *application)
+{
+	gtk_application_quit (application);
+}
+
 /**
  * main:
  **/
@@ -681,9 +689,9 @@ main (int argc, char *argv[])
 	GtkWidget *widget;
 	GtkFileFilter *filter;
 	GtkEntryCompletion *completion;
-	UniqueApp *unique_app;
+	GtkApplication *application;
 	gboolean ret;
-	GConfClient *gconf_client = NULL;
+	GSettings *settings = NULL;
 	gchar *option = NULL;
 	gchar *package = NULL;
 	gchar *with_array = NULL;
@@ -733,14 +741,7 @@ main (int argc, char *argv[])
 	gtk_init (&argc, &argv);
 
 	/* are we already activated? */
-	unique_app = unique_app_new ("org.freedesktop.PackageKit.ServicePack", NULL);
-	if (unique_app_is_running (unique_app)) {
-		egg_debug ("You have another instance running. This program will now close");
-		unique_app_send_message (unique_app, UNIQUE_ACTIVATE, NULL);
-		goto out_unique;
-	}
-	g_signal_connect (unique_app, "message-received",
-			  G_CALLBACK (gpk_pack_message_received_cb), NULL);
+	application = gtk_application_new ("org.freedesktop.PackageKit.ServicePack", &argc, &argv);
 
 	/* use a client to download packages */
 	client = pk_client_new ();
@@ -766,13 +767,15 @@ main (int argc, char *argv[])
 	}
 
 	main_window = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_pack"));
+	gtk_application_add_window (application, GTK_WINDOW (main_window));
 
 	/* Hide window first so that the dialogue resizes itself without redrawing */
 	gtk_widget_hide (main_window);
 	gtk_window_set_icon_name (GTK_WINDOW (main_window), GPK_ICON_SERVICE_PACK);
 
 	/* Get the main window quit */
-	g_signal_connect_swapped (main_window, "delete_event", G_CALLBACK (gtk_main_quit), NULL);
+	g_signal_connect (main_window, "delete-event",
+			  G_CALLBACK (gpk_pack_delete_event_cb), application);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "filechooserbutton_exclude"));
 	filter = gtk_file_filter_new ();
@@ -796,7 +799,7 @@ main (int argc, char *argv[])
 	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_pack_radio_copy_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
-	g_signal_connect_swapped (widget, "clicked", G_CALLBACK (gtk_main_quit), NULL);
+	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_pack_button_close_cb), application);
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_create"));
 	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_pack_button_create_cb), NULL);
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_help"));
@@ -806,8 +809,8 @@ main (int argc, char *argv[])
 	gtk_widget_hide (widget);
 
 	/* autocompletion can be turned off as it's slow */
-	gconf_client = gconf_client_get_default ();
-	ret = gconf_client_get_bool (gconf_client, GPK_CONF_AUTOCOMPLETE, NULL);
+	settings = g_settings_new (GPK_SETTINGS_SCHEMA);
+	ret = g_settings_get_boolean (settings, GPK_SETTINGS_AUTOCOMPLETE);
 	if (ret) {
 		/* create the completion object */
 		completion = gpk_package_entry_completion_new ();
@@ -844,15 +847,14 @@ main (int argc, char *argv[])
 
 	gtk_widget_show (main_window);
 
-	/* wait */
-	gtk_main ();
+	/* run */
+	gtk_application_run (application);
 
 out_build:
 	g_object_unref (builder);
-out_unique:
-	g_object_unref (unique_app);
-	if (gconf_client != NULL)
-		g_object_unref (gconf_client);
+	g_object_unref (application);
+	if (settings != NULL)
+		g_object_unref (settings);
 	if (control != NULL)
 		g_object_unref (control);
 	if (client != NULL)
