@@ -35,7 +35,7 @@
 #include <glib/gi18n.h>
 
 #include <gtk/gtk.h>
-#ifdef HAVE_LIBNOTIFY
+#ifdef HAVE_NOTIFY
 #include <libnotify/notify.h>
 #endif
 #include <packagekit-glib2/packagekit.h>
@@ -380,7 +380,7 @@ out:
 	return TRUE;
 }
 
-#ifdef HAVE_LIBNOTIFY
+#ifdef HAVE_NOTIFY
 /**
  * gpk_watch_libnotify_cb:
  **/
@@ -403,36 +403,6 @@ gpk_watch_libnotify_cb (NotifyNotification *notification, gchar *action, gpointe
 }
 #endif
 
-/**
- * gpk_watch_about_dialog_url_cb:
- **/
-static void
-gpk_watch_about_dialog_url_cb (GtkAboutDialog *about, const char *address, gpointer data)
-{
-	GError *error = NULL;
-	gboolean ret;
-	GdkScreen *gscreen;
-	gchar *url;
-	gchar *protocol = (gchar*) data;
-
-	if (protocol != NULL)
-		url = g_strconcat (protocol, address, NULL);
-	else
-		url = g_strdup (address);
-
-	gscreen = gtk_window_get_screen (GTK_WINDOW (about));
-
-	ret = gtk_show_uri (gscreen, url, gtk_get_current_event_time (), &error);
-
-	if (!ret) {
-		/* TRANSLATORS: We couldn't launch the tool, normally a packaging problem */
-		gpk_error_dialog (_("Internal error"), _("Failed to show url"), error->message);
-		g_error_free (error);
-	}
-
-	g_free (url);
-}
-
 /**
  * gpk_watch_show_about_cb:
  **/
@@ -470,9 +440,6 @@ gpk_watch_show_about_cb (GtkMenuItem *item, gpointer data)
 	license_trans = g_strconcat (_(license[0]), "", _(license[1]), "",
 				     _(license[2]), "", _(license[3]), "",  NULL);
 
-	gtk_about_dialog_set_url_hook (gpk_watch_about_dialog_url_cb, NULL, NULL);
-	gtk_about_dialog_set_email_hook (gpk_watch_about_dialog_url_cb, (gpointer) "mailto:", NULL);
-
 	gtk_window_set_default_icon_name (GPK_ICON_SOFTWARE_LOG);
 	gtk_show_about_dialog (NULL,
 			       "version", VERSION,
@@ -480,7 +447,7 @@ gpk_watch_show_about_cb (GtkMenuItem *item, gpointer data)
 			       "license", license_trans,
 			       "wrap-license", TRUE,	
 			       "website-label", _("PackageKit Website"),
-			       "website", "www.packagekit.org",
+			       "website", "http://www.packagekit.org",
 			       "comments", "PackageKit",
 			       "authors", authors,
 			       "documenters", documenters,
